@@ -50,7 +50,7 @@ class AWSHTTPResponse(HTTPResponse):
             return HTTPResponse._read_status(self)
 
 
-class AWSConnection(object):
+class AWSConnection:
     """Mixin for HTTPConnection that supports Expect 100-continue.
 
     This when mixed with a subclass of httplib.HTTPConnection (though
@@ -62,8 +62,9 @@ class AWSConnection(object):
     this against AWS services.
 
     """
+
     def __init__(self, *args, **kwargs):
-        super(AWSConnection, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self._original_response_cls = self.response_class
         # This variable is set when we receive an early response from the
         # server. If this value is set to True, any calls to send() are noops.
@@ -76,7 +77,7 @@ class AWSConnection(object):
         self._send_called = False
 
     def close(self):
-        super(AWSConnection, self).close()
+        super().close()
         # Reset all of our instance state we were tracking.
         self._response_received = False
         self._expect_header_set = False
@@ -138,8 +139,10 @@ class AWSConnection(object):
                 # server (possibly via a proxy) from which it has never seen a
                 # 100 (Continue) status, the client SHOULD NOT wait for an
                 # indefinite period before sending the request body.
-                logger.debug("No response seen from server, continuing to "
-                             "send the response body.")
+                logger.debug(
+                    "No response seen from server, continuing to "
+                    "send the response body."
+                )
         if message_body is not None:
             # message_body was not a string (i.e. it is a file), and
             # we must run the risk of Nagle.
@@ -167,8 +170,9 @@ class AWSConnection(object):
             parts = maybe_status_line.split(None, 2)
             if self._is_100_continue_status(maybe_status_line):
                 self._consume_headers(fp)
-                logger.debug("100 Continue response seen, "
-                             "now sending request body.")
+                logger.debug(
+                    "100 Continue response seen, " "now sending request body."
+                )
                 self._send_message_body(message_body)
             elif len(parts) == 3 and parts[0].startswith(b'HTTP/'):
                 # From the RFC:
@@ -183,12 +187,18 @@ class AWSConnection(object):
                 # So if we don't get a 100 Continue response, then
                 # whatever the server has sent back is the final response
                 # and don't send the message_body.
-                logger.debug("Received a non 100 Continue response "
-                             "from the server, NOT sending request body.")
-                status_tuple = (parts[0].decode('ascii'),
-                                int(parts[1]), parts[2].decode('ascii'))
+                logger.debug(
+                    "Received a non 100 Continue response "
+                    "from the server, NOT sending request body."
+                )
+                status_tuple = (
+                    parts[0].decode('ascii'),
+                    int(parts[1]),
+                    parts[2].decode('ascii'),
+                )
                 response_class = functools.partial(
-                    AWSHTTPResponse, status_tuple=status_tuple)
+                    AWSHTTPResponse, status_tuple=status_tuple
+                )
                 self.response_class = response_class
                 self._response_received = True
         finally:
@@ -210,22 +220,24 @@ class AWSConnection(object):
                 )
             self._send_called = True
             return
-        return super(AWSConnection, self).send(str)
+        return super().send(str)
 
     def _is_100_continue_status(self, maybe_status_line):
         parts = maybe_status_line.split(None, 2)
         # Check for HTTP/<version> 100 Continue\r\n
         return (
-            len(parts) >= 3 and parts[0].startswith(b'HTTP/') and
-            parts[1] == b'100')
+            len(parts) >= 2
+            and parts[0].startswith(b'HTTP/')
+            and parts[1] == b'100'
+        )
 
 
 class AWSHTTPConnection(AWSConnection, HTTPConnection):
-    """ An HTTPConnection that supports 100 Continue behavior. """
+    """An HTTPConnection that supports 100 Continue behavior."""
 
 
 class AWSHTTPSConnection(AWSConnection, VerifiedHTTPSConnection):
-    """ An HTTPSConnection that supports 100 Continue behavior. """
+    """An HTTPSConnection that supports 100 Continue behavior."""
 
 
 class AWSHTTPConnectionPool(HTTPConnectionPool):
@@ -236,8 +248,9 @@ class AWSHTTPSConnectionPool(HTTPSConnectionPool):
     ConnectionCls = AWSHTTPSConnection
 
 
-def prepare_request_dict(request_dict, endpoint_url, context=None,
-                         user_agent=None):
+def prepare_request_dict(
+    request_dict, endpoint_url, context=None, user_agent=None
+):
     """
     This method prepares a request dict to be created into an
     AWSRequestObject. This prepares the request dict by adding the
@@ -267,9 +280,9 @@ def prepare_request_dict(request_dict, endpoint_url, context=None,
         percent_encode_sequence = botocore.utils.percent_encode_sequence
         encoded_query_string = percent_encode_sequence(r['query_string'])
         if '?' not in url:
-            url += '?%s' % encoded_query_string
+            url += f'?{encoded_query_string}'
         else:
-            url += '&%s' % encoded_query_string
+            url += f'&{encoded_query_string}'
     r['url'] = url
     r['context'] = context
     if context is None:
@@ -329,7 +342,7 @@ def _urljoin(endpoint_url, url_path, host_prefix):
     return reconstructed
 
 
-class AWSRequestPreparer(object):
+class AWSRequestPreparer:
     """
     This class performs preparation on AWSRequest objects similar to that of
     the PreparedRequest class does in the requests library. However, the logic
@@ -349,6 +362,7 @@ class AWSRequestPreparer(object):
 
         This class does not prepare the method, auth or cookies.
     """
+
     def prepare(self, original):
         method = original.method
         url = self._prepare_url(original)
@@ -362,7 +376,7 @@ class AWSRequestPreparer(object):
         url = original.url
         if original.params:
             params = urlencode(list(original.params.items()), doseq=True)
-            url = '%s?%s' % (url, params)
+            url = f'{url}?{params}'
         return url
 
     def _prepare_headers(self, original, prepared_body=None):
@@ -410,7 +424,7 @@ class AWSRequestPreparer(object):
         return botocore.utils.determine_content_length(body)
 
 
-class AWSRequest(object):
+class AWSRequest:
     """Represents the elements of an HTTP request.
 
     This class was originally inspired by requests.models.Request, but has been
@@ -420,15 +434,16 @@ class AWSRequest(object):
 
     _REQUEST_PREPARER_CLS = AWSRequestPreparer
 
-    def __init__(self,
-                 method=None,
-                 url=None,
-                 headers=None,
-                 data=None,
-                 params=None,
-                 auth_path=None,
-                 stream_output=False):
-
+    def __init__(
+        self,
+        method=None,
+        url=None,
+        headers=None,
+        data=None,
+        params=None,
+        auth_path=None,
+        stream_output=False,
+    ):
         self._request_preparer = self._REQUEST_PREPARER_CLS()
 
         # Default empty dicts for dict params.
@@ -467,7 +482,7 @@ class AWSRequest(object):
         return body
 
 
-class AWSPreparedRequest(object):
+class AWSPreparedRequest:
     """A data class representing a finalized request to be sent over the wire.
 
     Requests at this stage should be treated as final, and the properties of
@@ -479,6 +494,7 @@ class AWSPreparedRequest(object):
     :ivar body: The HTTP body.
     :ivar stream_output: If the response for this request should be streamed.
     """
+
     def __init__(self, method, url, headers, body, stream_output):
         self.method = method
         self.url = url
@@ -517,7 +533,7 @@ class AWSPreparedRequest(object):
             raise UnseekableStreamError(stream_object=self.body)
 
 
-class AWSResponse(object):
+class AWSResponse:
     """A data class representing an HTTP response.
 
     This class was originally inspired by requests.models.Response, but has
@@ -547,7 +563,7 @@ class AWSResponse(object):
             # NOTE: requests would attempt to call stream and fall back
             # to a custom generator that would call read in a loop, but
             # we don't rely on this behavior
-            self._content = bytes().join(self.raw.stream()) or bytes()
+            self._content = b''.join(self.raw.stream()) or b''
 
         return self._content
 
@@ -566,7 +582,7 @@ class AWSResponse(object):
             return self.content.decode('utf-8')
 
 
-class _HeaderKey(object):
+class _HeaderKey:
     def __init__(self, key):
         self._key = key
         self._lower = key.lower()
@@ -585,7 +601,8 @@ class _HeaderKey(object):
 
 
 class HeadersDict(MutableMapping):
-    """A case-insenseitive dictionary to represent HTTP headers. """
+    """A case-insenseitive dictionary to represent HTTP headers."""
+
     def __init__(self, *args, **kwargs):
         self._dict = {}
         self.update(*args, **kwargs)
